@@ -1,17 +1,16 @@
 package Net::DNS::RR::DLV;
 
 #
-# $Id: DLV.pm 1179 2014-03-19 21:46:58Z willem $
+# $Id: DLV.pm 1192 2014-04-11 08:43:54Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1179 $)[1];
+$VERSION = (qw$LastChangedRevision: 1192 $)[1];
 
 
+use warnings;
 use strict;
 use base qw(Net::DNS::RR::DS);
 
-no warnings;
-
 =head1 NAME
 
 Net::DNS::RR::DLV - DNS DLV resource record
