@@ -1,10 +1,10 @@
 package Net::DNS::RR::NSEC3;
 
 #
-# $Id: NSEC3.pm 1302 2015-01-23 11:07:41Z willem $
+# $Id: NSEC3.pm 1193 2014-04-28 07:11:19Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1302 $)[1];
+$VERSION = (qw$LastChangedRevision: 1193 $)[1];
 
 
 use strict;
@@ -18,7 +18,6 @@ Net::DNS::RR::NSEC3 - DNS NSEC3 resource record
 
 
 use integer;
-
 use warnings;
 use Carp;
 use MIME::Base32;
@@ -109,8 +108,7 @@ sub parse_rdata {			## populate RR from rdata in argument list
 	$self->algorithm(shift);
 	$self->flags(shift);
 	$self->iterations(shift);
-	my $salt = shift;
-	$self->salt($salt) unless $salt eq '-';
+	$self->salt(shift);
 	$self->hnxtname(shift);
 	$self->typelist(@_);
 }
@@ -235,6 +233,7 @@ sub optout {
 
 ########################################
 
+
 sub hashalgo {				## historical
 	&algorithm;
 }
@@ -268,6 +267,7 @@ sub name2hash {
 	return lc $base32hex;
 }
 
+
 1;
 __END__
 
@@ -332,9 +332,9 @@ integer.  The value is between 0 and 65535, inclusive.
     $salt = $rr->salt;
     $rr->salt( $salt );
 
-The Salt field is represented as a contiguous sequence of hexadecimal
-digits. A "-" (unquoted) is used in string format to indicate that the
-salt field is absent. 
+The Salt field is represented by a contiguous sequence of hexadecimal
+digits. This field is represented as "-" (without quotes) when the
+used in string format to indicate that the salt field is absent. 
 
 =head2 saltbin
 
